@@ -6,8 +6,8 @@ import datetime
 from jsonrpcclient.clients.http_client import HTTPClient
 from jsonrpcclient.clients.tornado_client import TornadoClient
 import tornado.web
-from utils.qtum_utils.qtum import Qtum
-from utils.bip32keys.bip32keys import Bip32Keys
+from qtum_utils.qtum import Qtum
+from bip32keys.bip32keys import Bip32Keys
 from .keys import SIGN_PRV_KEY, SIGN_PUB_KEY
 
 
